@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.12
+#!/usr/local/bin/python3.13
 
 ##===--- iwyu_tool.py -----------------------------------------------------===##
 #
@@ -53,7 +53,7 @@ LINES_RE = re.compile(r'^- (.*?)  // lines ([0-9]+)-[0-9]+$')
 GENERAL, ADD, REMOVE, LIST = range(4)
 
 
-def clang_formatter(output):
+def clang_formatter(output, style):
     """ Process iwyu's output into something clang-like. """
     formatted = []
 
@@ -84,15 +84,19 @@ def clang_formatter(output):
         elif state[0] == ADD:
             match = ADD_RE.match(line)
             if match:
-                formatted.append("%s:1:1: error: add '%s' (%s)" %
-                                 (state[1], match.group(1), match.group(2)))
+                formatted.append("%s:1:1: %s: add '%s' (%s)" %
+                                 (state[1],
+                                  style,
+                                  match.group(1),
+                                  match.group(2)))
             else:
-                formatted.append("%s:1:1: error: add '%s'" % (state[1], line))
+                formatted.append("%s:1:1: %s: add '%s'" %
+                                 (state[1], style, line))
         elif state[0] == REMOVE:
             match = LINES_RE.match(line)
             line_no = match.group(2) if match else '1'
-            formatted.append("%s:%s:1: error: superfluous '%s'" %
-                             (state[1], line_no, match.group(1)))
+            formatted.append("%s:%s:1: %s: superfluous '%s'" %
+                             (state[1], line_no, style, match.group(1)))
 
     return os.linesep.join(formatted)
 
@@ -100,7 +104,8 @@ def clang_formatter(output):
 DEFAULT_FORMAT = 'iwyu'
 FORMATTERS = {
     'iwyu': lambda output: output,
-    'clang': clang_formatter
+    'clang': lambda output: clang_formatter(output, style="error"),
+    'clang-warning': lambda output: clang_formatter(output, style="warning"),
 }
 
 
@@ -492,9 +497,13 @@ def _bootstrap(sys_argv):
                         choices=FORMATTERS.keys(), default=DEFAULT_FORMAT,
                         help='Output format (default: %s)' % DEFAULT_FORMAT)
     parser.add_argument('-j', '--jobs', type=int, default=1,
-                        help='Number of concurrent subprocesses')
+                        nargs='?', const=0,
+                        help=('Number of concurrent subprocesses. If zero, '
+                              'will try to match the logical cores of the '
+                              'system.'))
     parser.add_argument('-l', '--load', type=float, default=0,
-                        help='Do not start new jobs if the 1min load average is greater than the provided value')
+                        help=('Do not start new jobs if the 1min load average '
+                              'is greater than the provided value'))
     parser.add_argument('-p', metavar='<build-path>', required=True,
                         help='Compilation database path', dest='dbpath')
     parser.add_argument('source', nargs='*',
@@ -512,8 +521,12 @@ def _bootstrap(sys_argv):
     argv, extra_args = partition_args(sys_argv[1:])
     args = parser.parse_args(argv)
 
+    jobs = args.jobs
+    if jobs == 0:
+        jobs = os.cpu_count() or 1
+
     return main(args.dbpath, args.source, args.verbose,
-                FORMATTERS[args.output_format], args.jobs, args.load, extra_args)
+                FORMATTERS[args.output_format], jobs, args.load, extra_args)
 
 
 if __name__ == '__main__':
